<?php

namespace Bixo\Statistic\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Statistic\Models\Statistics;

class StatisticsPolicy
{

    /**
     * Determine if the given user can view the statistics.
     *
     * @param UserPolicy $user
     * @param Statistics $statistics
     *
     * @return bool
     */
    public function view(UserPolicy $user, Statistics $statistics)
    {
        if ($user->canDo('statistic.statistics.view') && $user->isAdmin()) {
            return true;
        }

        return $statistics->user_id == user_id() && $statistics->user_type == user_type();
    }

    /**
     * Determine if the given user can create a statistics.
     *
     * @param UserPolicy $user
     * @param Statistics $statistics
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('statistic.statistics.create');
    }

    /**
     * Determine if the given user can update the given statistics.
     *
     * @param UserPolicy $user
     * @param Statistics $statistics
     *
     * @return bool
     */
    public function update(UserPolicy $user, Statistics $statistics)
    {
        if ($user->canDo('statistic.statistics.edit') && $user->isAdmin()) {
            return true;
        }

        return $statistics->user_id == user_id() && $statistics->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given statistics.
     *
     * @param UserPolicy $user
     * @param Statistics $statistics
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Statistics $statistics)
    {
        return $statistics->user_id == user_id() && $statistics->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given statistics.
     *
     * @param UserPolicy $user
     * @param Statistics $statistics
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Statistics $statistics)
    {
        if ($user->canDo('statistic.statistics.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given statistics.
     *
     * @param UserPolicy $user
     * @param Statistics $statistics
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Statistics $statistics)
    {
        if ($user->canDo('statistic.statistics.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
